@@ -307,11 +307,7 @@ void FancyTabBar::paintEvent(QPaintEvent* event)
     }
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-void FancyTab::enterEvent(QEvent*)
-#else
 void FancyTab::enterEvent(QEnterEvent*)
-#endif
 {
     fadeIn();
 }
@@ -623,7 +619,7 @@ void FancyTabWidget::SetMode(FancyTabWidget::Mode mode)
         side_layout_->insertWidget(0, bar);
         tab_bar_ = bar;
 
-        foreach (const Item &item, items_) {
+        for (const Item &item : std::as_const(items_)) {
             if (item.type_ == Item::Type_Spacer) {
                 bar->addSpacer(item.spacer_size_);
             }
@@ -722,7 +718,7 @@ void FancyTabWidget::MakeTabBar(QTabBar::Shape shape, bool text, bool icons,
         side_layout_->insertWidget(0, bar);
     }
 
-    foreach (const Item &item, items_) {
+    for (const Item &item : std::as_const(items_)) {
         if (item.type_ != Item::Type_Tab) {
             continue;
         }
