@@ -18,19 +18,21 @@
 #include "autosaver.h"
 
 #include <QTimerEvent>
+#include <QCoreApplication>
 
 #define SAVE_DELAY 1000 * 10 // 10 seconds
 
 AutoSaver::AutoSaver(QObject* parent)
     : QObject(parent)
 {
+    connect(qApp, &QCoreApplication::aboutToQuit, this, &AutoSaver::saveIfNecessary);
 }
 
 void AutoSaver::saveIfNecessary()
 {
     if (m_timer.isActive()) {
         m_timer.stop();
-        emit save();
+        Q_EMIT save();
     }
 }
 
@@ -45,7 +47,7 @@ void AutoSaver::timerEvent(QTimerEvent* event)
 {
     if (event->timerId() == m_timer.timerId()) {
         m_timer.stop();
-        emit save();
+        Q_EMIT save();
     }
 
     QObject::timerEvent(event);
