@@ -1,6 +1,7 @@
 /* ============================================================
 * Falkon - Qt web browser
 * Copyright (C) 2014-2018 David Rosca <nowrep@gmail.com>
+* Copyright (C) 2020-2025 Juraj Oravec <jurajoravec@mailo.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,9 +25,15 @@ const int sessionVersion = 0x0004;
 
 FALKON_EXPORT const char *APPNAME = "Falkon";
 FALKON_EXPORT const char *VERSION = FALKON_VERSION;
-FALKON_EXPORT const char *AUTHOR = "David Rosca";
-FALKON_EXPORT const char *COPYRIGHT = "2010-2018";
+FALKON_EXPORT const char *AUTHOR = "Juraj Oravec";
+FALKON_EXPORT const char *COPYRIGHT = "2020-2025";
 FALKON_EXPORT const char *WWWADDRESS = "https://falkon.org";
 FALKON_EXPORT const char *BUGSADDRESS = "https://bugs.kde.org/describecomponents.cgi?product=Falkon";
 FALKON_EXPORT const char *WIKIADDRESS = "https://userbase.kde.org/Falkon";
+
+const QList<AuthorInfo> AUTHORS = {
+    {QSL("Juraj Oravec"), QSL("jurajoravec@mailo.com"), 2020, 2025},
+    {QSL("David Rosca"), QSL("nowrep@gmail.com"), 2010, 2019},
+};
+
 }
