@@ -29,8 +29,8 @@
 
 BookmarksIcon::BookmarksIcon(QWidget* parent)
     : ClickableLabel(parent)
-    , m_view(0)
-    , m_bookmark(0)
+    , m_view(nullptr)
+    , m_bookmark(nullptr)
 {
     setObjectName("locationbar-bookmarkicon");
     setCursor(Qt::PointingHandCursor);
@@ -60,7 +60,7 @@ void BookmarksIcon::checkBookmark(const QUrl &url, bool forceCheck)
     }
 
     QList<BookmarkItem*> items = mApp->bookmarks()->searchBookmarks(url);
-    m_bookmark = items.isEmpty() ? 0 : items.at(0);
+    m_bookmark = items.isEmpty() ? nullptr : items.at(0);
 
     if (m_bookmark || mApp->plugins()->speedDial()->pageForUrl(url).isValid()) {
         setBookmarkSaved();
