@@ -53,6 +53,7 @@
 #include "sitesettingsattributesitem.h"
 #include "sitesettingshtml5item.h"
 #include "autoopenprotocolsdialog.h"
+#include "qzsettings.h"
 
 #include <QSettings>
 #include <QInputDialog>
@@ -242,6 +243,10 @@ Preferences::Preferences(BrowserWindow* window)
     ui->backgroundColorLoaded->setIconColor(bgColor);
     connect(ui->backgroundColorLoaded, &QAbstractButton::clicked, ui->backgroundColorLoaded, &MacToolButton::selectColorDialog);
     connect(ui->backgroundColorLoadedReset, &QAbstractButton::clicked, ui->backgroundColorLoaded, &MacToolButton::resetIconColor);
+
+    ui->loadedSwitchDelay->setValue(settings.value(QSL("LoadedSwitchDelay"), 250).toInt());
+    ui->defaultSideBarWidth->setValue(settings.value(QSL("DefaultSideBarWidth"), qzSettings->defaultSideBarWidth).toInt());
+
     settings.endGroup();
 
     //TABS
@@ -323,6 +328,11 @@ Preferences::Preferences(BrowserWindow* window)
 #else
     ui->forceDarkMode->hide();
 #endif
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    ui->allowImageAnimation->setChecked(settings.value(QSL("allowImageAnimation"), true).toBool());
+#else
+    ui->allowImageAnimation->hide();
+#endif
 
     int prefferColorSchemeSetting = settings.value(QSL("prefferColorScheme"), Qz::ColorScheme_Auto).toInt();
 #if QTGUI_VERSION >= QT_VERSION_CHECK(6, 5, 0)
@@ -972,6 +982,8 @@ void Preferences::saveSettings()
     settings.setValue(QSL("showNavigationToolbar"), ui->showNavigationToolbar->isChecked());
     settings.setValue(QSL("BackgroundColorLoading"), ui->backgroundColorLoading->iconColor());
     settings.setValue(QSL("BackgroundColorLoaded"), ui->backgroundColorLoaded->iconColor());
+    settings.setValue(QSL("LoadedSwitchDelay"), ui->loadedSwitchDelay->value());
+    settings.setValue(QSL("DefaultSideBarWidth"), ui->defaultSideBarWidth->value());
     settings.endGroup();
 
     //TABS
@@ -1053,6 +1065,9 @@ void Preferences::saveSettings()
 #endif
 #if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     settings.setValue(QSL("forceDarkMode"), ui->forceDarkMode->isChecked());
+#endif
+#if QTWEBENGINECORE_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    settings.setValue(QSL("allowImageAnimation"), ui->allowImageAnimation->isChecked());
 #endif
     settings.setValue(QSL("prefferColorScheme"), ui->prefferColorScheme->currentData().toInt());
 #ifdef Q_OS_WIN
