@@ -35,14 +35,6 @@ public:
     void requestPermissions(WebPage* page, const QUrl &origin, const QWebEnginePage::Feature &feature);
     void rememberPermissions(const QUrl &origin, const QWebEnginePage::Feature &feature,
                              const QWebEnginePage::PermissionPolicy &policy);
-
-    void loadSettings();
-
-private:
-    void saveSettings();
-
-    QHash<QWebEnginePage::Feature, QStringList> m_granted;
-    QHash<QWebEnginePage::Feature, QStringList> m_denied;
 };
 
 #endif // HTML5PERMISSIONSMANAGER_H
