@@ -18,6 +18,7 @@
 #include "webinspector.h"
 #include "mainapplication.h"
 #include "networkmanager.h"
+#include "qzsettings.h"
 #include "settings.h"
 #include "webview.h"
 #include "webpage.h"
@@ -26,24 +27,36 @@
 #include <QJsonObject>
 #include <QJsonDocument>
 #include <QNetworkReply>
+#include <QTimer>
 #include <QWebEngineSettings>
 #include <QtWebEngineWidgetsVersion>
 
 QList<QWebEngineView*> WebInspector::s_views;
 
 WebInspector::WebInspector(QWidget *parent)
-    : QWebEngineView(parent)
+    : WebInspector(mApp->webProfile(), parent)
+{
+}
+
+WebInspector::WebInspector(QWebEngineProfile *profile, QWidget *parent)
+    : QWebEngineView(profile, parent)
     , m_view(nullptr)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setObjectName(QSL("web-inspector"));
     setMinimumHeight(80);
 
+    /* Custom background color while the page is loading */
+    page()->setBackgroundColor(qzSettings->backgroundColorLoading);
+
     m_height = Settings().value(QSL("Web-Inspector/height"), 80).toInt();
     m_windowSize = Settings().value(QSL("Web-Inspector/windowSize"), QSize(640, 480)).toSize();
 
     registerView(this);
 
+    /* Page settings needed for WebInspector to work correctly */
+    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, true);
+
     connect(page(), &QWebEnginePage::windowCloseRequested, this, &WebInspector::deleteLater);
     connect(page(), &QWebEnginePage::loadFinished, this, &WebInspector::loadFinished);
 }
@@ -100,6 +113,11 @@ void WebInspector::unregisterView(QWebEngineView *view)
 
 void WebInspector::loadFinished()
 {
+    /* Custom background color when page is loaded */
+    QTimer::singleShot(qzSettings->loadedSwitchDelay, this, [this](){
+        page()->setBackgroundColor(qzSettings->backgroundColorLoaded);
+    });
+
     // Inspect element
     if (m_inspectElement) {
         m_view->triggerPageAction(QWebEnginePage::InspectElement);
